wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_id_response_200_task_attempt_output_item_status_type_5 API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_id_response_200_task_attempt_output_item_status_type_5

View Source

    1from enum import Enum
    2
    3
    4class V1TaskGetByIdResponse200TaskAttemptOutputItemStatusType5(str, Enum):
    5    STARTED = "Started"
    6
    7    def __str__(self) -> str:
    8        return str(self.value)

class V1TaskGetByIdResponse200TaskAttemptOutputItemStatusType5(builtins.str, enum.Enum): View Source

    5class V1TaskGetByIdResponse200TaskAttemptOutputItemStatusType5(str, Enum):
    6    STARTED = "Started"
    7
    8    def __str__(self) -> str:
    9        return str(self.value)

An enumeration.

STARTED = <V1TaskGetByIdResponse200TaskAttemptOutputItemStatusType5.STARTED: 'Started'>

##### Inherited Members

enum.Enum
  name
  value
builtins.str
  encode
  replace
  split
  rsplit
  join
  capitalize
  casefold
  title
  center
  count
  expandtabs
  find
  partition
  index
  ljust
  lower
  lstrip
  rfind
  rindex
  rjust
  rstrip
  rpartition
  splitlines
  strip
  swapcase
  translate
  upper
  startswith
  endswith
  removeprefix
  removesuffix
  isascii
  islower
  isupper
  istitle
  isspace
  isdecimal
  isdigit
  isnumeric
  isalpha
  isalnum
  isidentifier
  isprintable
  zfill
  format
  format_map
  maketrans